@@ -1,10 +1,10 @@
-/* $Id: VBoxPciInternal.h 100877 2015-06-09 14:23:56Z bird $ */
+/* $Id: VBoxPciInternal.h 118839 2017-10-28 15:14:05Z bird $ */
 /** @file
  * VBoxPci - PCI driver (Host), Internal Header.
  */
 
 /*
- * Copyright (C) 2011-2015 Oracle Corporation
+ * Copyright (C) 2011-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -13,9 +13,18 @@
  * Foundation, in version 2 as it comes in the "COPYING" file of the
  * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ *
+ * The contents of this file may alternatively be used under the terms
+ * of the Common Development and Distribution License Version 1.0
+ * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
+ * VirtualBox OSE distribution, in which case the provisions of the
+ * CDDL are applicable instead of those of the GPL.
+ *
+ * You may elect to license modified versions of this file under the
+ * terms and conditions of either the GPL or the CDDL or both.
  */
 
-#ifndef ___VBoPciInternal_h___
+#ifndef ___VBoxPciInternal_h___
 #define ___VBoxPciInternal_h___
 
 #include <VBox/sup.h>
