@@ -1,10 +1,10 @@
-/* $Id: strprintf.cpp 83687 2013-02-08 12:50:49Z fmehnert $ */
+/* $Id: strprintf.cpp 118412 2017-10-17 14:26:02Z bird $ */
 /** @file
  * IPRT - String Formatters.
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,18 +25,18 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include <iprt/string.h>
 #include "internal/iprt.h"
 
 #include <iprt/assert.h>
 
 
-/*******************************************************************************
-*   Structures and Typedefs                                                    *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Structures and Typedefs                                                                                                      *
+*********************************************************************************************************************************/
 /** strbufoutput() argument structure. */
 typedef struct STRBUFARG
 {
@@ -49,9 +49,9 @@ typedef struct STRBUFARG
 typedef STRBUFARG *PSTRBUFARG;
 
 
-/*******************************************************************************
-*   Internal Functions                                                         *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Internal Functions                                                                                                           *
+*********************************************************************************************************************************/
 static DECLCALLBACK(size_t) strbufoutput(void *pvArg, const char *pachChars, size_t cbChars);
 
 
@@ -66,30 +66,62 @@ static DECLCALLBACK(size_t) strbufoutput(void *pvArg, const char *pachChars, siz
 static DECLCALLBACK(size_t) strbufoutput(void *pvArg, const char *pachChars, size_t cbChars)
 {
     PSTRBUFARG  pArg = (PSTRBUFARG)pvArg;
+    char *pszCur = pArg->psz; /* We actually have to spell this out for VS2010, or it will load for each case. */
 
     cbChars = RT_MIN(pArg->cch, cbChars);
     if (cbChars)
     {
-        memcpy(pArg->psz, pachChars, cbChars);
         pArg->cch -= cbChars;
-        pArg->psz += cbChars;
+
+        /* Note! For VS2010/64 we need at least 7 case statements before it generates a jump table. */
+        switch (cbChars)
+        {
+            default:
+                memcpy(pszCur, pachChars, cbChars);
+                break;
+            case 8: pszCur[7] = pachChars[7]; RT_FALL_THRU();
+            case 7: pszCur[6] = pachChars[6]; RT_FALL_THRU();
+            case 6: pszCur[5] = pachChars[5]; RT_FALL_THRU();
+            case 5: pszCur[4] = pachChars[4]; RT_FALL_THRU();
+            case 4: pszCur[3] = pachChars[3]; RT_FALL_THRU();
+            case 3: pszCur[2] = pachChars[2]; RT_FALL_THRU();
+            case 2: pszCur[1] = pachChars[1]; RT_FALL_THRU();
+            case 1: pszCur[0] = pachChars[0]; RT_FALL_THRU();
+            case 0:
+                break;
+        }
+        pArg->psz = pszCur += cbChars;
     }
-    *pArg->psz = '\0';
+    *pszCur = '\0';
 
     return cbChars;
 }
 
 
+RTDECL(size_t) RTStrPrintf(char *pszBuffer, size_t cchBuffer, const char *pszFormat, ...)
+{
+    /* Explicitly inline RTStrPrintfV + RTStrPrintfExV here because this is a frequently use API. */
+    STRBUFARG Arg;
+    va_list args;
+    size_t cbRet;
+
+    AssertMsgReturn(cchBuffer, ("Excellent idea! Format a string with no space for the output!\n"), 0);
+    Arg.psz = pszBuffer;
+    Arg.cch = cchBuffer - 1;
+
+    va_start(args, pszFormat);
+    cbRet = RTStrFormatV(strbufoutput, &Arg, NULL, NULL, pszFormat, args);
+    va_end(args);
+
+    return cbRet;
+}
+RT_EXPORT_SYMBOL(RTStrPrintf);
+
+
 RTDECL(size_t) RTStrPrintfExV(PFNSTRFORMAT pfnFormat, void *pvArg, char *pszBuffer, size_t cchBuffer, const char *pszFormat, va_list args)
 {
     STRBUFARG Arg;
-
-    if (!cchBuffer)
-    {
-        AssertMsgFailed(("Excellent idea! Format a string with no space for the output!\n"));
-        return 0;
-    }
-
+    AssertMsgReturn(cchBuffer, ("Excellent idea! Format a string with no space for the output!\n"), 0);
     Arg.psz = pszBuffer;
     Arg.cch = cchBuffer - 1;
     return RTStrFormatV(strbufoutput, &Arg, pfnFormat, pvArg, pszFormat, args);
@@ -115,15 +147,3 @@ RTDECL(size_t) RTStrPrintfEx(PFNSTRFORMAT pfnFormat, void *pvArg, char *pszBuffe
 }
 RT_EXPORT_SYMBOL(RTStrPrintfEx);
 
-
-RTDECL(size_t) RTStrPrintf(char *pszBuffer, size_t cchBuffer, const char *pszFormat, ...)
-{
-    va_list args;
-    size_t cbRet;
-    va_start(args, pszFormat);
-    cbRet = RTStrPrintfV(pszBuffer, cchBuffer, pszFormat, args);
-    va_end(args);
-    return cbRet;
-}
-RT_EXPORT_SYMBOL(RTStrPrintf);
-
